=========
Catalogue
=========

This is an essential Oscar app which exposes functionality to manage your
product catalogue.
:class:`oscar.apps.catalogue.abstract_models.AbstractProduct`
is its main model.
The catalogue app also includes views specific to viewing a list or
individual products.

Abstract models
---------------

.. automodule:: oscar.apps.catalogue.abstract_models
    :members:

Views
-----
.. automodule:: oscar.apps.catalogue.views
    :members:
